==> ejc-sdsjproject-impl-3.0.1-20210909.084307-4-sources.jar: com/ejianc/business/projectapply/service/impl/ProjectChangeServiceImpl.java <==
package com.ejianc.business.projectapply.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.projectapply.bean.ExecutiveAgentEntity;
import com.ejianc.business.projectapply.bean.ProjectApplyEntity;
import com.ejianc.business.projectapply.bean.ProjectChangeEntity;
import com.ejianc.business.projectapply.mapper.ProjectChangeMapper;
import com.ejianc.business.projectapply.service.IProjectApplyService;
import com.ejianc.business.projectapply.service.IProjectChangeService;
import com.ejianc.business.projectapply.vo.ExecutiveAgentVO;
import com.ejianc.business.projectapply.vo.ProjectApplyVO;
import com.ejianc.business.projectapply.vo.ProjectChangeVO;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;
import com.ejianc.framework.skeleton.template.BaseVO;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.*;

/**
 * 项目变更
 *
 * @author liyj
 * @Description: 项目变更
 * @date 2021/9/8 10:01
 */
@Service(value = "projectChangeService")
public class ProjectChangeServiceImpl extends BaseServiceImpl<ProjectChangeMapper, ProjectChangeEntity> implements IProjectChangeService {

    @Autowired
    private ProjectChangeMapper projectChangeMapper;

    @Override
    public List<ProjectChangeEntity> getAllByProjectId(Long projectId) {
        QueryWrapper<ProjectChangeEntity> query = new QueryWrapper<>();
        query.eq("dr", BaseVO.DR_UNDELETE);
        query.eq("project_id", projectId);

        return projectChangeMapper.selectList(query);
    }

    @Autowired
    private IProjectApplyService projectApplyService;
	@Autowired
	private SessionManager sessionManager;

    @Autowired
    private IProjectChangeService projectChangeService;

	@Override
	public CommonResponse<ProjectApplyVO> saveChange(ProjectApplyVO vo) {
		//校验执行主题
        Set<String> repeatCheck = new HashSet<>();
        if(CollectionUtils.isNotEmpty(vo.getExecutiveAgentList())) {
            //重新将所有执行主体名称汇总
            StringBuilder executiveAgentNames = new StringBuilder();
            String repeatCheckStr = null;
            for(ExecutiveAgentVO e : vo.getExecutiveAgentList()) {
                if(!"del".equals(e.getRowState())) {
                    executiveAgentNames.append(e.getExecutiveAgentName()).append(",");
                    e.setProjectSplit(vo.getProjectSplit());
                    repeatCheckStr = getRepeatCheckStr(e.getSplitType(), e.getExecutiveAgentId());
                    if(e.getProjectSplit() && repeatCheck.contains(repeatCheckStr)) {
                        return CommonResponse.error("保存失败，执行主体"+e.getExecutiveAgentName()+"["+vo.getProjectSplit()+"]"+"重复！");
                    } else {
                        repeatCheck.add(repeatCheckStr);
                    }
                }
            }

            vo.setExecutiveAgentNames(executiveAgentNames.substring(0, executiveAgentNames.length()-1));
        }
        if(StringUtils.isBlank(vo.getExecutiveAgentNames())) {
            return CommonResponse.error("保存失败，执行主体不能为空！");
        }

		//1、查询之前的项目信息；
        ProjectApplyEntity oldEntity = projectApplyService.selectById(vo.getId());
    	//2、判断两次的数据是否一致，不一致则添加到变更内容中
    	//主表
        String changeContent = "";
        boolean nameChange = false;
        //是否需要拆分、项目名称(中文)、项目名称(英文)、项目类型、计划开工/竣工日期
        if(!vo.getCnName().equals(oldEntity.getCnName())){
        	//项目名称(中文)
        	changeContent += ("[项目名称(中文)]：由"+'"'+oldEntity.getCnName()+'"'+"改为"+'"'+vo.getCnName()+'"');
        	nameChange = true;
        	oldEntity.setCnName(vo.getCnName());
        }
        if((StringUtils.isBlank(vo.getEnName())&&StringUtils.isNotBlank(oldEntity.getEnName())) ||
        		(StringUtils.isBlank(oldEntity.getEnName())&&StringUtils.isNotBlank(vo.getEnName())) ||
        		(StringUtils.isNotBlank(oldEntity.getEnName())&&StringUtils.isNotBlank(vo.getEnName())&&(!vo.getEnName().equals(oldEntity.getEnName())))){
        	//项目名称(英文)
        	changeContent += ("[项目名称(英文)]：由"+'"'+oldEntity.getEnName()+'"'+"改为"+'"'+vo.getEnName()+'"');
        	nameChange = true;
        	oldEntity.setEnName(vo.getEnName());
        }
        if(nameChange){
        	if(StringUtils.isNotBlank(oldEntity.getUsedNames())){
        		oldEntity.setUsedNames(oldEntity.getUsedNames()+","+vo.getCnName()+(StringUtils.isBlank(vo.getEnName())?vo.getEnName():""));
        	}else{
        		oldEntity.setUsedNames(vo.getCnName()+(StringUtils.isBlank(vo.getEnName())?vo.getEnName():""));
        	}
        }
        if(!vo.getProjectType().equals(oldEntity.getProjectType())){
        	if(changeContent.length()>0){
        		changeContent += (","+"[项目类型]：由"+'"'+oldEntity.getProjectTypeName()+'"'+"改为"+'"'+vo.getProjectTypeName()+'"');
        	}else{
        		changeContent += ("[项目类型]：由"+'"'+oldEntity.getProjectTypeName()+'"'+"改为"+'"'+vo.getProjectTypeName()+'"');
        	}
        	//项目类型
        	oldEntity.setProjectType(vo.getProjectType());
        	oldEntity.setProjectTypeName(vo.getProjectTypeName());
        }
        if(!vo.getProjectClassification().equals(oldEntity.getProjectClassification())){
        	if(changeContent.length()>0){
        		changeContent += (","+"[国内/国外项目]：由"+'"'+oldEntity.getProjectClassification()+'"'+"改为"+'"'+vo.getProjectClassification()+'"');
        	}else{
        		changeContent += ("[国内/国外项目]：由"+'"'+oldEntity.getProjectClassification()+'"'+"改为"+'"'+vo.getProjectClassification()+'"');
        	}
        	//项目分类：国内-国内项目，国外-国外项目
        	oldEntity.setProjectClassification(vo.getProjectClassification());
        }

        if((StringUtils.isBlank(vo.getRemark())&&StringUtils.isNotBlank(oldEntity.getRemark())) ||
        		(StringUtils.isBlank(oldEntity.getRemark())&&StringUtils.isNotBlank(vo.getRemark())) ||
        		(StringUtils.isNotBlank(oldEntity.getRemark())&&StringUtils.isNotBlank(vo.getRemark())&&(!vo.getRemark().equals(oldEntity.getRemark())))){
        	//备注
        	changeContent += ("[备注]：由"+'"'+oldEntity.getEnName()+'"'+"改为"+'"'+vo.getEnName()+'"');
        	nameChange = true;
        	oldEntity.setRemark(vo.getRemark());
        }

        if(!vo.getProjectStartDate().equals(oldEntity.getProjectStartDate())){
        	//判断开工日期是否改变
        	SimpleDateFormat formatter = new SimpleDateFormat("yyyy-MM-dd");
        	String oldStart = formatter.format(oldEntity.getProjectStartDate());
        	String oldFinish = formatter.format(oldEntity.getProjectFinishDate());
        	String old = (oldStart + " - " + oldFinish);
        	String newStart = formatter.format(vo.getProjectStartDate());
        	String newFinish = formatter.format(vo.getProjectFinishDate());
        	String newd = (newStart + " - " + newFinish);
        	if(changeContent.length()>0){
        		changeContent += (","+"[计划开工/竣工日期]：由"+'"'+old+'"'+"改为"+'"'+newd+'"');
        	}else{
        		changeContent += ("[计划开工/竣工日期]：由"+'"'+old+'"'+"改为"+'"'+newd+'"');
        	}
        	oldEntity.setProjectStartDate(vo.getProjectStartDate());
        }else{
        	//判断竣工日期是否改变
        	if(!vo.getProjectFinishDate().equals(oldEntity.getProjectFinishDate())){
            	//判断开工日期是否改变
            	SimpleDateFormat formatter = new SimpleDateFormat("yyyy-MM-dd");
            	String oldStart = formatter.format(oldEntity.getProjectStartDate());
            	String oldFinish = formatter.format(oldEntity.getProjectFinishDate());
            	String old = (oldStart + " - " + oldFinish);
            	String newStart = formatter.format(vo.getProjectStartDate());
            	String newFinish = formatter.format(vo.getProjectFinishDate());
            	String newd = (newStart + " - " + newFinish);
            	if(changeContent.length()>0){
            		changeContent += (","+"[计划开工/竣工日期]：由"+'"'+old+'"'+"改为"+'"'+newd+'"');
            	}else{
            		changeContent += ("[计划开工/竣工日期]：由"+'"'+old+'"'+"改为"+'"'+newd+'"');
            	}
            	oldEntity.setProjectFinishDate(vo.getProjectFinishDate());
            }
        }
    	//子表--执行主体
        List<ExecutiveAgentVO> executiveAgentList = vo.getExecutiveAgentList();
        if(executiveAgentList!=null&&executiveAgentList.size()>0){
        	String content = "";
        	String oldContent = "";
        	boolean change = false;
        	Map<Long,ExecutiveAgentEntity> oldExecutiveMap = new HashMap<>();
        	if(oldEntity.getExecutiveAgentList()!=null&&oldEntity.getExecutiveAgentList().size()>0){
        		for(ExecutiveAgentEntity executiveAgentEntity : oldEntity.getExecutiveAgentList()){
        			oldExecutiveMap.put(executiveAgentEntity.getId(), executiveAgentEntity);
        			if(oldContent.length()>0){
        				oldContent = (","+(StringUtils.isNotBlank(executiveAgentEntity.getSplitType())?(executiveAgentEntity.getSplitType()+"-"):"")+executiveAgentEntity.getExecutiveAgentName());
            		}else{
            			oldContent = ((StringUtils.isNotBlank(executiveAgentEntity.getSplitType())?(executiveAgentEntity.getSplitType()+"-"):"")+executiveAgentEntity.getExecutiveAgentName());
            		}
        		}
        	}
        	for(ExecutiveAgentVO executiveAgentVO : executiveAgentList){
            	if("add".equals(executiveAgentVO.getRowState())){
            		change = true;
            		if(content.length()>0){
            			content = (","+(StringUtils.isNotBlank(executiveAgentVO.getSplitType())?(executiveAgentVO.getSplitType()+"-"):"")+executiveAgentVO.getExecutiveAgentName());
            		}else{
            			content = ((StringUtils.isNotBlank(executiveAgentVO.getSplitType())?(executiveAgentVO.getSplitType()+"-"):"")+executiveAgentVO.getExecutiveAgentName());
            		}
            	}else if("del".equals(executiveAgentVO.getRowState())){
            		change = true;
            	}else if("edit".equals(executiveAgentVO.getRowState())){
            		ExecutiveAgentEntity entity = oldExecutiveMap.get(executiveAgentVO.getId());
                    if(!entity.getSplitType().equals(executiveAgentVO.getSplitType())){
                    	change = true;
                    }
                    if(!entity.getExecutiveAgentId().equals(executiveAgentVO.getExecutiveAgentId())){
                    	change = true;
                    }
                    if(!entity.getRemark().equals(executiveAgentVO.getRemark())){
                    	change = true;
                    }
            		if(content.length()>0){
            			content = (","+(StringUtils.isNotBlank(executiveAgentVO.getSplitType())?(executiveAgentVO.getSplitType()+"-"):"")+executiveAgentVO.getExecutiveAgentName());
            		}else{
            			content = ((StringUtils.isNotBlank(executiveAgentVO.getSplitType())?(executiveAgentVO.getSplitType()+"-"):"")+executiveAgentVO.getExecutiveAgentName());
            		}
            	}else{
            		if(content.length()>0){
            			content = (","+(StringUtils.isNotBlank(executiveAgentVO.getSplitType())?(executiveAgentVO.getSplitType()+"-"):"")+executiveAgentVO.getExecutiveAgentName());
            		}else{
            			content = ((StringUtils.isNotBlank(executiveAgentVO.getSplitType())?(executiveAgentVO.getSplitType()+"-"):"")+executiveAgentVO.getExecutiveAgentName());
            		}
            	}
            }
        	if(change){
        		if(changeContent.length()>0){
            		changeContent += (","+"[执行主体]：由"+'"'+oldContent+'"'+"改为"+'"'+content+'"');
            	}else{
            		changeContent += ("[执行主体]：由"+'"'+oldContent+'"'+"改为"+'"'+content+'"');
            	}
        	}
        	List<ExecutiveAgentEntity> list = BeanMapper.mapList(executiveAgentList, ExecutiveAgentEntity.class);
        	oldEntity.setExecutiveAgentList(list);
        	oldEntity.setExecutiveAgentNames(vo.getExecutiveAgentNames());
        }
        projectApplyService.saveOrUpdate(oldEntity, false);
        ProjectChangeEntity projectChange = new ProjectChangeEntity();
        projectChange.setChangeUserName(sessionManager.getUserContext().getUserName());
        projectChange.setChangeContent(changeContent);
        projectChange.setProjectId(oldEntity.getId());
    	//保存变更记录
        this.saveOrUpdate(projectChange, false);
        ProjectApplyVO back = BeanMapper.map(oldEntity, ProjectApplyVO.class);

    	QueryWrapper<ProjectChangeEntity> queryWrapper = new QueryWrapper<>();
    	queryWrapper.eq("dr", 0);
    	queryWrapper.eq("project_id", oldEntity.getId());
		List<ProjectChangeEntity> list = projectChangeService.list(queryWrapper);
		List<ProjectChangeVO> backList = new ArrayList<>();
		if(list!=null&&list.size()>0){
			backList = BeanMapper.mapList(list, ProjectChangeVO.class);
		}
        back.setProjectChangeList(backList);
        return CommonResponse.success("保存成功！", back);
	}

    private String getRepeatCheckStr(String splitType, Long executiveAgentId) {
        if(StringUtils.isBlank(splitType)) {
            return executiveAgentId.toString();
        } else if(splitType.indexOf(",") < 0) {
            return splitType + executiveAgentId;
        } else {
            String[] typeArr = splitType.split(",");
            Arrays.sort(typeArr, String.CASE_INSENSITIVE_ORDER);
            return StringUtils.join(typeArr, ",") + executiveAgentId;
        }
    }
}

==> ejc-sdsjproject-impl-3.0.1-20210913.071916-14-sources.jar: com/ejianc/business/projectapply/service/impl/ProjectChangeServiceImpl.java <==
package com.ejianc.business.projectapply.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.projectapply.bean.ExecutiveAgentEntity;
import com.ejianc.business.projectapply.bean.ProjectApplyEntity;
import com.ejianc.business.projectapply.bean.ProjectChangeEntity;
import com.ejianc.business.projectapply.mapper.ProjectChangeMapper;
import com.ejianc.business.projectapply.service.IProjectApplyService;
import com.ejianc.business.projectapply.service.IProjectChangeService;
import com.ejianc.business.projectapply.vo.ExecutiveAgentVO;
import com.ejianc.business.projectapply.vo.ProjectApplyVO;
import com.ejianc.business.projectapply.vo.ProjectChangeVO;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;
import com.ejianc.framework.skeleton.template.BaseVO;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.*;

/**
 * 项目变更
 *
 * @author liyj
 * @Description: 项目变更
 * @date 2021/9/8 10:01
 */
@Service(value = "projectChangeService")
public class ProjectChangeServiceImpl extends BaseServiceImpl<ProjectChangeMapper, ProjectChangeEntity> implements IProjectChangeService {

    @Autowired
    private ProjectChangeMapper projectChangeMapper;

    @Override
    public List<ProjectChangeEntity> getAllByProjectId(Long projectId) {
        QueryWrapper<ProjectChangeEntity> query = new QueryWrapper<>();
        query.eq("dr", BaseVO.DR_UNDELETE);
        query.eq("project_id", projectId);

        return projectChangeMapper.selectList(query);
    }

    @Autowired
    private IProjectApplyService projectApplyService;
	@Autowired
	private SessionManager sessionManager;

    @Autowired
    private IProjectChangeService projectChangeService;

	@Override
	public CommonResponse<ProjectApplyVO> saveChange(ProjectApplyVO vo) {
		//校验执行主题
        Set<String> repeatCheck = new HashSet<>();
        if(CollectionUtils.isNotEmpty(vo.getExecutiveAgentList())) {
            //重新将所有执行主体名称汇总
            StringBuilder executiveAgentNames = new StringBuilder();
            String repeatCheckStr = null;
            for(ExecutiveAgentVO e : vo.getExecutiveAgentList()) {
                if(!"del".equals(e.getRowState())) {
                    executiveAgentNames.append(e.getExecutiveAgentName()).append(",");
                    e.setProjectSplit(vo.getProjectSplit());
                    repeatCheckStr = getRepeatCheckStr(e.getSplitType(), e.getExecutiveAgentId());
                    if(e.getProjectSplit() && repeatCheck.contains(repeatCheckStr)) {
                        return CommonResponse.error("保存失败，执行主体："+e.getExecutiveAgentName()+"["+e.getSplitType()+"]"+"重复！");
                    } else {
                        repeatCheck.add(repeatCheckStr);
                    }
                }
            }

            vo.setExecutiveAgentNames(executiveAgentNames.substring(0, executiveAgentNames.length()-1));
        }
        if(StringUtils.isBlank(vo.getExecutiveAgentNames())) {
            return CommonResponse.error("保存失败，执行主体不能为空！");
        }

		//1、查询之前的项目信息；
        ProjectApplyEntity oldEntity = projectApplyService.selectById(vo.getId());
        oldEntity.setProjectSplit(vo.getProjectSplit());
    	//2、判断两次的数据是否一致，不一致则添加到变更内容中
    	//主表
        String changeContent = "";
        boolean nameChange = false;
        String oldCnName = oldEntity.getCnName();
        String oldEnName = oldEntity.getEnName();
        
        //是否需要拆分、项目名称(中文)、项目名称(英文)、项目类型、计划开工/竣工日期
        if(!vo.getCnName().equals(oldEntity.getCnName())){
        	//项目名称(中文)
        	changeContent += ("[项目名称(中文)]：由"+'"'+(StringUtils.isNotBlank(oldEntity.getCnName())?oldEntity.getCnName():"")
        			+'"'+"改为"+'"'+(StringUtils.isNotBlank(vo.getCnName())?vo.getCnName():"")+'"');
        	nameChange = true;
        	oldEntity.setCnName(vo.getCnName());
        }
        if((StringUtils.isBlank(vo.getEnName())&&StringUtils.isNotBlank(oldEntity.getEnName())) ||
        		(StringUtils.isBlank(oldEntity.getEnName())&&StringUtils.isNotBlank(vo.getEnName())) ||
        		(StringUtils.isNotBlank(oldEntity.getEnName())&&StringUtils.isNotBlank(vo.getEnName())&&(!vo.getEnName().equals(oldEntity.getEnName())))){
        	//项目名称(英文)
        	if(changeContent.length()>0){
        		changeContent += (",[项目名称(英文)]：由"+'"'+(StringUtils.isNotBlank(oldEntity.getEnName())?oldEntity.getEnName():"")
            			+'"'+"改为"+'"'+(StringUtils.isNotBlank(vo.getEnName())?vo.getEnName():"")+'"');
        	}else{
        		changeContent += ("[项目名称(英文)]：由"+'"'+(StringUtils.isNotBlank(oldEntity.getEnName())?oldEntity.getEnName():"")
            			+'"'+"改为"+'"'+(StringUtils.isNotBlank(vo.getEnName())?vo.getEnName():"")+'"');
        	}
        	
        	nameChange = true;
        	oldEntity.setEnName(vo.getEnName());
        }
        if(nameChange){
        	if(StringUtils.isNotBlank(oldEntity.getUsedNames())){
        		oldEntity.setUsedNames(oldEntity.getUsedNames()+","+oldCnName+(StringUtils.isNotBlank(oldEnName)?oldEnName:""));
        	}else{
        		oldEntity.setUsedNames(oldCnName+(StringUtils.isNotBlank(oldEnName)?oldEnName:""));
        	}
        }
        if(!vo.getProjectType().equals(oldEntity.getProjectType())){
        	if(changeContent.length()>0){
        		changeContent += (","+"[项目类型]：由"+'"'+oldEntity.getProjectTypeName()+'"'+"改为"+'"'+vo.getProjectTypeName()+'"');
        	}else{
        		changeContent += ("[项目类型]：由"+'"'+oldEntity.getProjectTypeName()+'"'+"改为"+'"'+vo.getProjectTypeName()+'"');
        	}
        	//项目类型
        	oldEntity.setProjectType(vo.getProjectType());
        	oldEntity.setProjectTypeName(vo.getProjectTypeName());
        }
        if(!vo.getProjectClassification().equals(oldEntity.getProjectClassification())){
        	if(changeContent.length()>0){
        		changeContent += (","+"[国内/国外项目]：由"+'"'+oldEntity.getProjectClassification()+'"'+"改为"+'"'+vo.getProjectClassification()+'"');
        	}else{
        		changeContent += ("[国内/国外项目]：由"+'"'+oldEntity.getProjectClassification()+'"'+"改为"+'"'+vo.getProjectClassification()+'"');
        	}
        	//项目分类：国内-国内项目，国外-国外项目
        	oldEntity.setProjectClassification(vo.getProjectClassification());
        }

        if((StringUtils.isBlank(vo.getRemark())&&StringUtils.isNotBlank(oldEntity.getRemark())) ||
        		(StringUtils.isBlank(oldEntity.getRemark())&&StringUtils.isNotBlank(vo.getRemark())) ||
        		(StringUtils.isNotBlank(oldEntity.getRemark())&&StringUtils.isNotBlank(vo.getRemark())&&(!vo.getRemark().equals(oldEntity.getRemark())))){
        	//备注
        	if(changeContent.length()>0){
        		changeContent += (",[备注]：由"+'"'+(StringUtils.isNotBlank(oldEntity.getRemark())?oldEntity.getRemark():"")
            			+'"'+"改为"+'"'+(StringUtils.isNotBlank(vo.getRemark())?vo.getRemark():"")+'"');
        	}else{
        		changeContent += ("[备注]：由"+'"'+(StringUtils.isNotBlank(oldEntity.getRemark())?oldEntity.getRemark():"")
            			+'"'+"改为"+'"'+(StringUtils.isNotBlank(vo.getRemark())?vo.getRemark():"")+'"');
        	}
        	
        	nameChange = true;
        	oldEntity.setRemark(vo.getRemark());
        }

        if(!vo.getProjectStartDate().equals(oldEntity.getProjectStartDate())){
        	//判断开工日期是否改变
        	SimpleDateFormat formatter = new SimpleDateFormat("yyyy-MM-dd");
        	String oldStart = formatter.format(oldEntity.getProjectStartDate());
        	String oldFinish = formatter.format(oldEntity.getProjectFinishDate());
        	String old = (oldStart + " - " + oldFinish);
        	String newStart = formatter.format(vo.getProjectStartDate());
        	String newFinish = formatter.format(vo.getProjectFinishDate());
        	String newd = (newStart + " - " + newFinish);
        	if(changeContent.length()>0){
        		changeContent += (","+"[计划开工/竣工日期]：由"+'"'+old+'"'+"改为"+'"'+newd+'"');
        	}else{
        		changeContent += ("[计划开工/竣工日期]：由"+'"'+old+'"'+"改为"+'"'+newd+'"');
        	}
        	oldEntity.setProjectStartDate(vo.getProjectStartDate());
        }else{
        	//判断竣工日期是否改变
        	if(!vo.getProjectFinishDate().equals(oldEntity.getProjectFinishDate())){
            	//判断开工日期是否改变
            	SimpleDateFormat formatter = new SimpleDateFormat("yyyy-MM-dd");
            	String oldStart = formatter.format(oldEntity.getProjectStartDate());
            	String oldFinish = formatter.format(oldEntity.getProjectFinishDate());
            	String old = (oldStart + " - " + oldFinish);
            	String newStart = formatter.format(vo.getProjectStartDate());
            	String newFinish = formatter.format(vo.getProjectFinishDate());
            	String newd = (newStart + " - " + newFinish);
            	if(changeContent.length()>0){
            		changeContent += (","+"[计划开工/竣工日期]：由"+'"'+old+'"'+"改为"+'"'+newd+'"');
            	}else{
            		changeContent += ("[计划开工/竣工日期]：由"+'"'+old+'"'+"改为"+'"'+newd+'"');
            	}
            	oldEntity.setProjectFinishDate(vo.getProjectFinishDate());
            }
        }
    	//子表--执行主体
        List<ExecutiveAgentVO> executiveAgentList = vo.getExecutiveAgentList();
        if(executiveAgentList!=null&&executiveAgentList.size()>0){
        	String content = "";
        	String oldContent = "";
        	boolean change = false;
        	Map<Long,ExecutiveAgentEntity> oldExecutiveMap = new HashMap<>();
        	if(oldEntity.getExecutiveAgentList()!=null&&oldEntity.getExecutiveAgentList().size()>0){
        		for(ExecutiveAgentEntity executiveAgentEntity : oldEntity.getExecutiveAgentList()){
        			oldExecutiveMap.put(executiveAgentEntity.getId(), executiveAgentEntity);
        			if(oldContent.length()>0){
        				oldContent += (","+(StringUtils.isNotBlank(executiveAgentEntity.getSplitType())?(executiveAgentEntity.getSplitType()+"-"):"")+executiveAgentEntity.getExecutiveAgentName());
            		}else{
            			oldContent += ((StringUtils.isNotBlank(executiveAgentEntity.getSplitType())?(executiveAgentEntity.getSplitType()+"-"):"")+executiveAgentEntity.getExecutiveAgentName());
            		}
        		}
        	}
        	for(ExecutiveAgentVO executiveAgentVO : executiveAgentList){
            	if("add".equals(executiveAgentVO.getRowState())){
            		change = true;
            		if(content.length()>0){
            			content += (","+(StringUtils.isNotBlank(executiveAgentVO.getSplitType())?(executiveAgentVO.getSplitType()+"-"):"")+executiveAgentVO.getExecutiveAgentName());
            		}else{
            			content += ((StringUtils.isNotBlank(executiveAgentVO.getSplitType())?(executiveAgentVO.getSplitType()+"-"):"")+executiveAgentVO.getExecutiveAgentName());
            		}
            	}else if("del".equals(executiveAgentVO.getRowState())){
            		change = true;
            	}else if("edit".equals(executiveAgentVO.getRowState())){
            		ExecutiveAgentEntity entity = oldExecutiveMap.get(executiveAgentVO.getId());
                    if(!entity.getSplitType().equals(executiveAgentVO.getSplitType())){
                    	change = true;
                    }
                    if(!entity.getExecutiveAgentId().equals(executiveAgentVO.getExecutiveAgentId())){
                    	change = true;
                    }
                    if(!entity.getRemark().equals(executiveAgentVO.getRemark())){
                    	change = true;
                    }
            		if(content.length()>0){
            			content += (","+(StringUtils.isNotBlank(executiveAgentVO.getSplitType())?(executiveAgentVO.getSplitType()+"-"):"")+executiveAgentVO.getExecutiveAgentName());
            		}else{
            			content += ((StringUtils.isNotBlank(executiveAgentVO.getSplitType())?(executiveAgentVO.getSplitType()+"-"):"")+executiveAgentVO.getExecutiveAgentName());
            		}
            	}else{
            		if(content.length()>0){
            			content += (","+(StringUtils.isNotBlank(executiveAgentVO.getSplitType())?(executiveAgentVO.getSplitType()+"-"):"")+executiveAgentVO.getExecutiveAgentName());
            		}else{
            			content += ((StringUtils.isNotBlank(executiveAgentVO.getSplitType())?(executiveAgentVO.getSplitType()+"-"):"")+executiveAgentVO.getExecutiveAgentName());
            		}
            	}
            }
        	if(change){
        		if(changeContent.length()>0){
            		changeContent += (","+"[执行主体]：由"+'"'+oldContent+'"'+"改为"+'"'+content+'"');
            	}else{
            		changeContent += ("[执行主体]：由"+'"'+oldContent+'"'+"改为"+'"'+content+'"');
            	}
        	}
        	List<ExecutiveAgentEntity> list = BeanMapper.mapList(executiveAgentList, ExecutiveAgentEntity.class);
        	oldEntity.setExecutiveAgentList(list);
        	oldEntity.setExecutiveAgentNames(vo.getExecutiveAgentNames());
        }
        projectApplyService.saveOrUpdate(oldEntity, false);
        ProjectChangeEntity projectChange = new ProjectChangeEntity();
        projectChange.setChangeUserName(sessionManager.getUserContext().getUserName());
        projectChange.setChangeContent(changeContent);
        projectChange.setProjectId(oldEntity.getId());
    	//保存变更记录
        this.saveOrUpdate(projectChange, false);
        ProjectApplyVO back = BeanMapper.map(oldEntity, ProjectApplyVO.class);

    	QueryWrapper<ProjectChangeEntity> queryWrapper = new QueryWrapper<>();
    	queryWrapper.eq("dr", 0);
    	queryWrapper.eq("project_id", oldEntity.getId());
		List<ProjectChangeEntity> list = projectChangeService.list(queryWrapper);
		List<ProjectChangeVO> backList = new ArrayList<>();
		if(list!=null&&list.size()>0){
			backList = BeanMapper.mapList(list, ProjectChangeVO.class);
		}
        back.setProjectChangeList(backList);
        return CommonResponse.success("保存成功！", back);
	}

    private String getRepeatCheckStr(String splitType, Long executiveAgentId) {
        if(StringUtils.isBlank(splitType)) {
            return executiveAgentId.toString();
        } else if(splitType.indexOf(",") < 0) {
            return splitType + executiveAgentId;
        } else {
            String[] typeArr = splitType.split(",");
            Arrays.sort(typeArr, String.CASE_INSENSITIVE_ORDER);
            return StringUtils.join(typeArr, ",") + executiveAgentId;
        }
    }
}
